library("gnlr")
cod <- read.table("cod.dat")
names(cod) <- c("sal","temp","ox","t1","h1","t2","h2","t3","h3","t4","h4")
attach(cod)
sal <- rep(sal,4)
temp <- rep(temp,4)
ox <- rep(ox,4)
sal2 <- sal^2/10
temp2 <- temp^2/10
ox2 <- ox^2/10
st <- sal*temp/10
so <- sal*ox/10
to <- temp*ox/10
hatch <- c(h1,h2,h3,h4)
total <- c(t1,t2,t3,t4)
y <- cbind(hatch,total-hatch)
mu <- function(p,linear) exp(linear)/(1+exp(linear))

-sum(lchoose(total,hatch)+hatch*log(hatch)+(total-hatch)*log(total-hatch)-total*log(total))
-sum(lchoose(total,hatch)+hatch*log(hatch)+(total-hatch)*log(total-hatch)-total*log(total))+length(total)
p.i <- rep((h1+h2+h3+h4)/(t1+t2+t3+t4),4)
-sum(lchoose(total,hatch)+hatch*log(p.i)+(total-hatch)*log(1-p.i))
-sum(lchoose(total,hatch)+hatch*log(p.i)+(total-hatch)*log(1-p.i))+length(h1)

# untransformed variables

glm(y~sal+sal2,family=binomial)

print(z1 <- gnlr(y,p=c(-1.5,0.2,-0.13),dist="binomial",mu=mu,
	linear=~sal+sal2))
z1$maxlik-211.837 # 2642.350
print(z2 <- gnlr(y,p=c(-1.5,0.3,-0.13,4),dist="beta binomial",mu=mu,
	linear=~sal+sal2))
z2$maxlik-211.837 # 206.1171
print(z3 <- gnlr(y,p=c(-1.5,0.3,-0.13,13,-0.5,0),dist="beta binomial",mu=mu,
	linear=list(~sal+sal2,~sal+sal2)))
z3$maxlik-211.837 # 197.4302

glm(y~temp+temp2,family=binomial)

print(z4 <- gnlr(y,p=c(-3.5,1.6,-1.3),dist="binomial",mu=mu,
	linear=~temp+temp2))
z4$maxlik-211.837 # 2458.411
print(z5 <- gnlr(y,p=c(-3.5,1.6,-1.3,4),dist="beta binomial",mu=mu,
	linear=~temp+temp2))
z5$maxlik-211.837 # 203.6933
print(z6 <- gnlr(y,p=c(-3.5,1.6,-1.3,2,0,0),dist="beta binomial",mu=mu,
	linear=list(~temp+temp2,~temp+temp2)))
z6$maxlik-211.837 # 196.4587

glm(y~ox+ox2,family=binomial)

print(z7 <- gnlr(y,p=c(-1,0.28,-0.74),dist="binomial",mu=mu,
	linear=~ox+ox2))
z7$maxlik-211.837 # 3616.289
print(z8 <- gnlr(y,p=c(-1,0.28,-0.74,4),dist="beta binomial",mu=mu,
	linear=~ox+ox2))
z8$maxlik-211.837 # 216.661
print(z9 <- gnlr(y,p=c(-1,0.28,-0.74,3,0,0),dist="beta binomial",mu=mu,
	linear=list(~ox+ox2,~ox+ox2)))
z9$maxlik-211.837 # 210.7625

glm(y~sal+sal2+temp+temp2+st,family=binomial)

print(z10 <- gnlr(y,p=c(-1.76,0.02,-0.04,1.4,-1.2,0.03),dist="binomial",mu=mu,
	linear=~sal+sal2+temp+temp2+st))
z10$maxlik-211.837 # 1474.715
print(z11 <- gnlr(y,p=c(-1.76,0.02,-0.04,1.4,-1.2,0.03,1),
	dist="beta binomial",mu=mu,linear=~sal+sal2+temp+temp2+st))
z11$maxlik-211.837 # 179.3958
print(z12 <- gnlr(y,p=c(-1.76,0.02,-0.04,1.4,-1.2,0.03,1,0,0,0,0,0),
	dist="beta binomial",mu=mu,
	linear=list(~sal+sal2+temp+temp2+st,~sal+sal2+temp+temp2+st)))
z12$maxlik-211.837 # 166.3197

p <- z12$coefficients
#probability
fp1 <- function(x1,x2) {
	tt<-exp(p[1]+p[2]*x1+p[3]*x1^2/10+p[4]*x2+p[5]*x2^2/10+p[6]*x1*x2/10)
	tt/(1+tt)}
zz1p <- matrix(nrow=29,ncol=17)
for (i in 1:29) for (j in 1:17) {
	x1 <- (i+27)/2
	x2 <- (j+3)/2
	zz1p[i,j] <- fp1(x1,x2)}
contour(zz1p,(1:29+27)/2,(1:17+3)/2)
title(main="Probability - Cod (untransformed)",xlab="Salinity",ylab="Temperature")
fp1(14,6)
range(zz1p)

#dispersion
fd1 <- function(x1,x2) {
	exp(p[7]+p[8]*x1+p[9]*x1^2/10+p[10]*x2+p[11]*x2^2/10+p[12]*x1*x2/10)}
zz1d <- matrix(nrow=29,ncol=17)
for (i in 1:29) for (j in 1:17) {
	x1 <- (i+27)/2
	x2 <- (j+3)/2
	zz1d[i,j] <- fd1(x1,x2)}
contour(zz1d,(1:29+27)/2,(1:17+3)/2)
title(main="Dispersion - Cod (untransformed)",xlab="Salinity",ylab="Temperature")
fd1(14,6)
range(zz1d)

#correlation
fc1 <- function(x1,x2) {
	1/(1+exp(p[7]+p[8]*x1+p[9]*x1^2/10+p[10]*x2+p[11]*x2^2/10+p[12]*x1*x2/10))}
zz1c <- matrix(nrow=29,ncol=17)
for (i in 1:29) for (j in 1:17) {
	x1 <- (i+27)/2
	x2 <- (j+3)/2
	zz1c[i,j] <- fc1(x1,x2)}
contour(zz1c,(1:29+27)/2,(1:17+3)/2)
title(main="Correlation - Cod (untransformed)",xlab="Salinity",ylab="Temperature")
fc1(14,6)
range(zz1c)

glm(y~sal+sal2+temp+temp2+ox+ox2+st+so+to,family=binomial)

mu <- function(p,linear) exp(linear)/(1+exp(linear))
print(z20 <- gnlr(y,p=c(0.6515,1.6,-0.29,-1.23,-0.05,-0.14,-0.24,0.1025,0.45,-0.482),
	dist="binomial",mu=mu,linear=~sal+sal2+temp+temp2+ox+ox2+st+so+to))
z20$maxlik-211.837 # 887.9428

print(z21 <- gnlr(y,p=c(0.6515,-0.1362,-0.29,-0.515,1.6,-1.2276,-0.24,0.1025,0.45,-0.482,2.5),
	dist="beta binomial",mu=mu,linear=~sal+sal2+temp+temp2+ox+ox2+st+so+to,stepmx=2))
z21$maxlik-211.837 # 159.7405

p<-c(0,.32,-0.18,0.07,-0.51,-0.44,-0.14,0.14,0.27,0.26,1,-0.13,0.02,0.15,-0.22,-0.07,0.5,0.28,-0.23,-0.23)
print(z22 <- gnlr(y,p=p,
	dist="beta binomial",mu=mu,linear=list(~sal+sal2+temp+temp2+ox+ox2+st+so+to,~sal+sal2+temp+temp2+ox+ox2+st+so+to),gradtl=0.000001,ndigit=14,stepmx=1,typsiz=rep(1,20),print.level=2
))
z22$maxlik-211.837 # 151.7554
c(0,.32,-0.18,0.07,-0.51,-0.44,-0.14,0.14,0.27,0.26,1,-0.13,0.02,0.15,-0.22,-0.07,0.5,0.28,-0.23,-0.23)
# transformed variables

s <- 100/sal
s2 <- s^2
t <- 10/sqrt(temp)
t2 <- t^2
o <- ox^2/100
o2 <- o^2
stt <- s*t
sot <- s*o
tot <- t*o

glm(y~s+s2+t+t2+o+o2+stt+sot+tot,family=binomial)

mu <- function(p,linear) exp(linear)/(1+exp(linear))
print(z30 <- gnlr(y,p=c(-26,3.7,-0.3,6.2,-0.7,6,-2,0.1,-1.2,0.9),
	dist="binomial",mu=mu,linear=~s+s2+t+t2+o+o2+stt+sot+tot,stepmx=1,print.level=2))
z30$maxlik-211.837 # 600.2615

print(z31 <- gnlr(y,p=c(-26,3.7,-0.3,6.2,-0.7,6,-2,0.1,-1.2,0.9,3.1),
	dist="beta binomial",mu=mu,linear=~s+s2+t+t2+o+o2+stt+sot+tot,gradtl=0.000001,ndigit=12,stepmx=1,itnlim=200))
z31$maxlik-211.837 # 137.2160

print(z32 <- gnlr(y,p=c(-26,3.7,-0.3,6.2,-0.7,6,-2,0.1,-1.2,0.9,2,0,0,0,0,0,0,0,0,0),
	dist="beta binomial",mu=mu,linear=list(~s+s2+t+t2+o+o2+stt+sot+tot,~sal+sal2+temp+temp2+ox+ox2+st+so+to),gradtl=0.0000001,ndigit=14,steptl=0.0000001,stepmx=1,itnlim=300))
z32$maxlik-211.837 # 128.6389

print(z33 <- gnlr(y,p=c(-27.2,3.95,-0.29,6.42,-0.77,5.65,-1.8,0.089,-1.33,0.98,3.29,2.38,-0.085,-3.11,0.35,0.089,-0.061,-0.15,-1.57,1.88),
	dist="beta binomial",mu=mu,linear=list(~s+s2+t+t2+o+o2+stt+sot+tot,~s+s2+t+t2+o+o2+stt+sot+tot),gradtl=0.0000001,ndigit=14,steptl=0.0000001,stepmx=1,itnlim=300))
z33$maxlik-211.837 # 129.2491

#p <- z32$coefficients
p <- z33$coefficients

aa <- -c(p[2],p[4],p[6])
bb <- matrix(c(2*p[3],p[8],p[9],p[8],2*p[5],p[10],p[9],p[10],2*p[7]),nrow=3)
pp <- solve(bb,aa)
c(100/pp[1],100/pp[2]^2,10*sqrt(pp[3]))

x3 <- 10 # 6.6
#probability
fp2 <- function(x1,x2) {
	tt<-exp(p[1]+p[2]/x1*100+p[3]/x1^2*10000+p[4]/sqrt(x2)*10+p[5]/x2*100+p[6]*x3^2/100+p[7]*x3^4/10000+p[8]/x1*100/sqrt(x2)*10+p[9]/x1*100*x3^2/100+p[10]/sqrt(x2)*10*x3^2/100)
	tt/(1+tt)}
zz2p <- matrix(nrow=29,ncol=17)
for (i in 1:29) for (j in 1:17) zz2p[i,j] <- fp2((i+27)/2,(j+3)/2)
contour(zz2p,(1:29+27)/2,(1:17+3)/2)
title(main="Probability - Cod (transformed)",xlab="Salinity",ylab="Temperature")
fp2(15.5,4.2)
range(zz2p)

#dispersion
fd2 <- function(x1,x2) {
	exp(p[11]+p[12]/x1*100+p[13]/x1^2*10000+p[14]/sqrt(x2)*10+p[15]/x2*100+p[16]*x3^2/100+p[17]*x3^4/10000+p[18]/x1*100/sqrt(x2)*10+p[19]/x1*100*x3^2/100+p[20]/sqrt(x2)*10*x3^2/100)}
zz2d <- matrix(nrow=29,ncol=17)
for (i in 1:29) for (j in 1:17) zz2d[i,j] <- fd2((i+27)/2,(j+3)/2)
contour(zz2d,(1:29+27)/2,(1:17+3)/2)
title(main="Dispersion - Cod (transformed)",xlab="Salinity",ylab="Temperature")
fd2(26,10)
range(zz2d)

#correlation
fc2 <- function(x1,x2) {
	1/(1+exp(p[11]+p[12]/x1*100+p[13]/x1^2*10000+p[14]/sqrt(x2)*10+p[15]/x2*100+p[16]*x3^2/100+p[17]*x3^4/10000+p[18]/x1*100/sqrt(x2)*10+p[19]/x1*100*x3^2/100+p[20]/sqrt(x2)*10*x3^2/100))}
zz2c <- matrix(nrow=29,ncol=17)
for (i in 1:29) for (j in 1:17) zz2c[i,j] <- fc2((i+27)/2,(j+3)/2)
contour(zz2c,(1:29+27)/2,(1:17+3)/2,zc=seq(0,0.32,by=0.02))
title(main="Correlation - Cod (transformed)",xlab="Salinity",ylab="Temperature")
fc2(26,10)
range(zz2c)

#correlation
#fc2 <- function(x1,x2) {
#	1/(1+exp(p[11]+p[12]*x1+p[13]*x1^2/10+p[14]*x2+p[15]*x2^2/10+p[16]*x3+p[17]*x3^2/10+p[18]*x1*x2/10+p[19]*x1*x3/10+p[20]*x2*x3/10))}
#zz2c <- matrix(nrow=29,ncol=17)
#for (i in 1:29) for (j in 1:17) zz2c[i,j] <- fc2((i+27)/2,(j+3)/2)
#contour(zz2c,(1:29+27)/2,(1:17+3)/2)
#title(main="Correlation - Cod (transformed)",xlab="Salinity",ylab="Temperature")
#fc2(28,7)
#range(zz2c)

x2<-4  #6
#probability
fp3 <- function(x1,x3) {
	tt<-exp(p[1]+p[2]/x1*100+p[3]/x1^2*10000+p[4]/sqrt(x2)*10+p[5]/x2*100+p[6]*x3^2/100+p[7]*x3^4/10000+p[8]/x1*100/sqrt(x2)*10+p[9]/x1*100*x3^2/100+p[10]/sqrt(x2)*10*x3^2/100)
	tt/(1+tt)}
zz3p <- matrix(nrow=29,ncol=20)
for (i in 1:29) for (j in 1:20) zz3p[i,j] <- fp3((i+27)/2,j/2+2.5)
contour(zz3p,(1:29+27)/2,(1:20)/2+2.5)
title(main="Probability - Cod (transformed)",xlab="Salinity",ylab="Oxygen")
fp3(14,4)
range(zz3p)

#correlation
fc3 <- function(x1,x3) {
	1/(1+exp(p[11]+p[12]/x1*100+p[13]/x1^2*10000+p[14]/sqrt(x2)*10+p[15]/x2*100+p[16]*x3^2/100+p[17]*x3^4/10000+p[18]/x1*100/sqrt(x2)*10+p[19]/x1*100*x3^2/100+p[20]/sqrt(x2)*10*x3^2/100))}
zz3c <- matrix(nrow=29,ncol=20)
for (i in 1:29) for (j in 1:20) zz3c[i,j] <- fc3((i+27)/2,j/2+2.5)
contour(zz3c,(1:29+27)/2,(1:20)/2+2.5,zc=seq(0,0.32,by=0.02))
title(main="Correlation - Cod (transformed)",xlab="Salinity",ylab="Oxygen")
fc3(14,4)
range(zz3c)

#correlation
#fc3 <- function(x1,x3) {
#	1/(1+exp(p[11]+p[12]*x1+p[13]*x1^2/10+p[14]*x2+p[15]*x2^2/10+p[16]*x3+p[17]*x3^2/10+p[18]*x1*x2/10+p[19]*x1*x3/10+p[20]*x2*x3/10))}
#zz3c <- matrix(nrow=29,ncol=20)
#for (i in 1:29) for (j in 1:20) zz3c[i,j] <- fc3((i+27)/2,j/2+2.5)
#contour(zz3c,(1:29+27)/2,(1:20)/2+2.5)
#title(main="Correlation - Cod (transformed)",xlab="Salinity",ylab="Oxygen")
#fc3(14,4)
#range(zz3c)

x1<- 20
#probability
fp4 <- function(x2,x3) {
	tt<-exp(p[1]+p[2]/x1*100+p[3]/x1^2*10000+p[4]/sqrt(x2)*10+p[5]/x2*100+p[6]*x3^2/100+p[7]*x3^4/10000+p[8]/x1*100/sqrt(x2)*10+p[9]/x1*100*x3^2/100+p[10]/sqrt(x2)*10*x3^2/100)
	tt/(1+tt)}
zz4p <- matrix(nrow=17,ncol=20)
for (i in 1:17) for (j in 1:20) zz4p[i,j] <- fp4((i+3)/2,j/2+2.5)
contour(zz4p,(1:17+3)/2,(1:20)/2+2.5)
title(main="Probability - Cod (transformed)",xlab="Temperature",ylab="Oxygen")
fp4(4,10.5)
range(zz4p)

#correlation
fc4 <- function(x2,x3) {
	1/(1+exp(p[11]+p[12]/x1*100+p[13]/x1^2*10000+p[14]/sqrt(x2)*10+p[15]/x2*100+p[16]*x3^2/100+p[17]*x3^4/10000+p[18]/x1*100/sqrt(x2)*10+p[19]/x1*100*x3^2/100+p[20]/sqrt(x2)*10*x3^2/100))}
zz4c <- matrix(nrow=17,ncol=20)
for (i in 1:17) for (j in 1:20) zz4c[i,j] <- fc4((i+3)/2,j/2+2.5)
contour(zz4c,(1:17+3)/2,(1:20)/2+2.5,zc=seq(0,0.32,by=0.02))
title(main="Correlation - Cod (transformed)",xlab="Temperature",ylab="Oxygen")
fc4(4,10.5)
range(zz4c)

#correlation
#fc4 <- function(x2,x3) {
#	1/(1+exp(p[11]+p[12]*x1+p[13]*x1^2/10+p[14]*x2+p[15]*x2^2/10+p[16]*x3+p[17]*x3^2/10+p[18]*x1*x2/10+p[19]*x1*x3/10+p[20]*x2*x3/10))}
#zz4c <- matrix(nrow=17,ncol=20)
#for (i in 1:17) for (j in 1:20) zz4c[i,j] <- fc4((i+3)/2,j/2+2.5)
#contour(zz4c,(1:17+3)/2,(1:20)/2+2.5)
#title(main="Correlation - Cod (transformed)",xlab="Temperature",ylab="Oxygen")
#fc2(4,10.5)
#range(zz2c)

#postscript(file="/home/jlindsey/texts/articles/fish/cod.eps",landscape=FALSE,height=7.5)
par(mfcol=c(2,3))
contour(zz2p,(1:29+27)/2,(1:17+3)/2)
title(xlab="Salinity",ylab="Temperature")
contour(zz2c,(1:29+27)/2,(1:17+3)/2,zc=seq(0,0.32,by=0.02))
title(xlab="Salinity",ylab="Temperature")
contour(zz3p,(1:29+27)/2,(1:20)/2+2.5)
title(xlab="Salinity",ylab="Oxygen")
contour(zz3c,(1:29+27)/2,(1:20)/2+2.5,zc=seq(0,0.32,by=0.02))
title(xlab="Salinity",ylab="Oxygen")
contour(zz4p,(1:17+3)/2,(1:20)/2+2.5)
title(xlab="Temperature",ylab="Oxygen")
contour(zz4c,(1:17+3)/2,(1:20)/2+2.5,zc=seq(0,0.32,by=0.02))
title(xlab="Temperature",ylab="Oxygen")
#x11()

print(z34 <- gnlr(y,p=c(-26.29,3.96,-0.3,6,-0.74,5.7,-1.8,0.11,-1.37,1.05,1.14,0.7,0.08,-0.3,0.1,0.09,-0.2,-1.4,1.7),
	dist="beta binomial",mu=mu,linear=list(~s+s2+t+t2+o+o2+stt+sot+tot,~s+s2+t+t2+o+stt+sot+tot),gradtl=0.0000001,ndigit=14,steptl=0.0000001
))
z34$maxlik-211.837 # 129.2415

print(z35 <- gnlr(y,p=c(-26.29,3.96,-0.3,6,-0.74,5.7,-1.8,0.11,-1.37,1.05,1.14,0.7,0.08,0.1,0.085,-0.2,-1.4,1.7),
	dist="beta binomial",mu=mu,linear=list(~s+s2+t+t2+o+o2+stt+sot+tot,~s+s2+t2+o+stt+sot+tot),gradtl=0.0000001,ndigit=14,steptl=0.0000001
))
z35$maxlik-211.837 # 129.6136

print(z36 <- gnlr(y,p=c(-26.29,3.96,-0.3,6,-0.74,5.7,-1.8,0.11,-1.37,1.05,1.14,0.7,0.08,0.1,-0.2,-1.4,1.7),
	dist="beta binomial",mu=mu,linear=list(~s+s2+t+t2+o+o2+stt+sot+tot,~s+s2+t2+stt+sot+tot),gradtl=0.0000001,ndigit=14,steptl=0.0000001
))
z36$maxlik-211.837 # 129.6105

print(z37 <- gnlr(y,p=c(-26.29,3.96,-0.3,6,-0.74,5.7,-1.8,0.11,-1.37,1.05,1.14,0.08,0.1,-0.2,-1.4,1.7),
	dist="beta binomial",mu=mu,linear=list(~s+s2+t+t2+o+o2+stt+sot+tot,~s2+t2+stt+sot+tot),gradtl=0.0000001,ndigit=14,steptl=0.0000001
))
z37$maxlik-211.837 # 130.0897

print(z38 <- gnlr(y,p=c(-26.29,3.96,-0.3,6,-0.74,5.7,-1.8,0.11,-1.37,1.05,1.14,0.08,-0.2,-1.4,1.7),
	dist="beta binomial",mu=mu,linear=list(~s+s2+t+t2+o+o2+stt+sot+tot,~s2+stt+sot+tot),gradtl=0.0000001,ndigit=14,steptl=0.0000001,stepmx=1,itnlim=300,print.level=2))
z38$maxlik-211.837 # 130.3515

print(z39 <- gnlr(y,p=c(-26.29,3.96,-0.3,6,-0.74,5.7,-1.8,0.11,-1.37,1.05,1.14,0.08,-1.4,1.7),
	dist="beta binomial",mu=mu,linear=list(~s+s2+t+t2+o+o2+stt+sot+tot,~s2+sot+tot),gradtl=0.0000001,ndigit=14,steptl=0.0000001
))
z39$maxlik-211.837 # 131.5791

p <- z38$coefficients

aa <- -c(p[2],p[4],p[6])
bb <- matrix(c(2*p[3],p[8],p[9],p[8],2*p[5],p[10],p[9],p[10],2*p[7]),nrow=3)
pp <- solve(bb,aa)
c(100/pp[1],100/pp[2]^2,10*sqrt(pp[3]))

x3 <- 11.7 # 6.6
#probability
fp5 <- function(x1,x2) {
	tt<-exp(p[1]+p[2]/x1*100+p[3]/x1^2*10000+p[4]/sqrt(x2)*10+p[5]/x2*100+p[6]*x3^2/100+p[7]*x3^4/10000+p[8]/x1*100/sqrt(x2)*10+p[9]/x1*100*x3^2/100+p[10]/sqrt(x2)*10*x3^2/100)
	tt/(1+tt)}
zz5p <- matrix(nrow=33,ncol=17)
for (i in 1:33) for (j in 1:17) zz5p[i,j] <- fp5((i+23)/2,(j+3)/2)
contour((1:33+23)/2,(1:17+3)/2,zz5p)
points(sal[1:19],temp[1:19],pch=20)
title(main="Probability - Cod (transformed)",xlab="Salinity",ylab="Temperature")
fp5(22.3,3.5)
range(zz5p)

#correlation
fc5 <- function(x1,x2) {
	1/(1+exp(p[11]+p[12]/x1^2*10000+p[13]/x1*100/sqrt(x2)*10+p[14]/x1*100*x3^2/100+p[15]/sqrt(x2)*10*x3^2/100))}
zz5c <- matrix(nrow=33,ncol=17)
for (i in 1:33) for (j in 1:17) zz5c[i,j] <- fc5((i+23)/2,(j+3)/2)
contour((1:33+23)/2,(1:17+3)/2,zz5c,levels=seq(0,1,by=0.02))
points(sal[1:19],temp[1:19],pch=20)
title(main="Correlation - Cod (transformed)",xlab="Salinity",ylab="Temperature")
fc5(22.3,3.5)
range(zz5c)

x2<-3.5  #6
#probability
fp6 <- function(x1,x3) {
	tt<-exp(p[1]+p[2]/x1*100+p[3]/x1^2*10000+p[4]/sqrt(x2)*10+p[5]/x2*100+p[6]*x3^2/100+p[7]*x3^4/10000+p[8]/x1*100/sqrt(x2)*10+p[9]/x1*100*x3^2/100+p[10]/sqrt(x2)*10*x3^2/100)
	tt/(1+tt)}
zz6p <- matrix(nrow=33,ncol=20)
for (i in 1:33) for (j in 1:20) zz6p[i,j] <- fp6((i+23)/2,j/2+2.5)
contour((1:33+23)/2,(1:20)/2+2.5,zz6p)
points(sal[1:19],ox[1:19],pch=20)
title(main="Probability - Cod (transformed)",xlab="Salinity",ylab="Oxygen")
fp6(22.3,11.7)
range(zz6p)

#correlation
fc6 <- function(x1,x3) {
	1/(1+exp(p[11]+p[12]/x1^2*10000+p[13]/x1*100/sqrt(x2)*10+p[14]/x1*100*x3^2/100+p[15]/sqrt(x2)*10*x3^2/100))}
zz6c <- matrix(nrow=33,ncol=20)
for (i in 1:33) for (j in 1:20) zz6c[i,j] <- fc6((i+23)/2,j/2+2.5)
contour((1:33+23)/2,(1:20)/2+2.5,zz6c,levels=seq(0,1,by=0.02))
points(sal[1:19],ox[1:19],pch=20)
title(main="Correlation - Cod (transformed)",xlab="Salinity",ylab="Oxygen")
fc6(23.3,11.7)
range(zz6c)

x1<- 22.3
#probability
fp7 <- function(x2,x3) {
	tt<-exp(p[1]+p[2]/x1*100+p[3]/x1^2*10000+p[4]/sqrt(x2)*10+p[5]/x2*100+p[6]*x3^2/100+p[7]*x3^4/10000+p[8]/x1*100/sqrt(x2)*10+p[9]/x1*100*x3^2/100+p[10]/sqrt(x2)*10*x3^2/100)
	tt/(1+tt)}
zz7p <- matrix(nrow=17,ncol=20)
for (i in 1:17) for (j in 1:20) zz7p[i,j] <- fp7((i+3)/2,j/2+2.5)
contour((1:17+3)/2,(1:20)/2+2.5,zz7p)
points(temp[1:19],ox[1:19],pch=20)
title(main="Probability - Cod (transformed)",xlab="Temperature",ylab="Oxygen")
fp7(3.5,11.7)
range(zz7p)

#correlation
fc7 <- function(x2,x3) {
	1/(1+exp(p[11]+p[12]/x1^2*10000+p[13]/x1*100/sqrt(x2)*10+p[14]/x1*100*x3^2/100+p[15]/sqrt(x2)*10*x3^2/100))}
zz7c <- matrix(nrow=17,ncol=20)
for (i in 1:17) for (j in 1:20) zz7c[i,j] <- fc7((i+3)/2,j/2+2.5)
contour((1:17+3)/2,(1:20)/2+2.5,zz7c,levels=seq(0,1,by=0.02))
points(temp[1:19],ox[1:19],pch=20)
title(main="Correlation - Cod (transformed)",xlab="Temperature",ylab="Oxygen")
fc7(3.5,11.7)
range(zz7c)

#postscript(file="/home/jlindsey/texts/articles/fish/cod2.eps",landscape=FALSE,height=7.5)
par(mfcol=c(2,3))
contour((1:33+23)/2,(1:17+3)/2,zz5p)
points(sal[1:19],temp[1:19],pch=20)
title(xlab="Salinity",ylab="Temperature")
contour((1:33+23)/2,(1:17+3)/2,zz5c,levels=seq(0,0.72,by=0.02))
points(sal[1:19],temp[1:19],pch=20)
title(xlab="Salinity",ylab="Temperature")
contour((1:33+23)/2,(1:20)/2+2.5,zz6p)
points(sal[1:19],ox[1:19],pch=20)
title(xlab="Salinity",ylab="Oxygen")
contour((1:33+23)/2,(1:20)/2+2.5,zz6c,levels=seq(0,1,by=0.02))
points(sal[1:19],ox[1:19],pch=20)
title(xlab="Salinity",ylab="Oxygen")
contour((1:17+3)/2,(1:20)/2+2.5,zz7p)
points(temp[1:19],ox[1:19],pch=20)
title(xlab="Temperature",ylab="Oxygen")
contour((1:17+3)/2,(1:20)/2+2.5,zz7c,levels=seq(0,1,by=0.02))
points(temp[1:19],ox[1:19],pch=20)
title(xlab="Temperature",ylab="Oxygen")
#x11()

#mu <- function(p){
#	tt <- exp(p[1]+p[2]/sal+p[3]/sal2)
#	tt/(1+tt)}
#print(z1t <- gnlr(y,p=c(-10.86,372.5,-2866.2),dist="binomial",mu=mu))
#z1t$maxlik-211.837
#mu <- function(p){
#	tt <- exp(p[1]+p[2]*sal^(p[4]/1000)+p[3]*sal2^(p[4]/1000))
#	tt/(1+tt)}
#print(z1t <- gnlr(y,p=c(-10.86,372.5,-2866.2,-1000),dist="binomial",mu=mu))
